@@ -511,7 +511,6 @@ public:
 			QString sirikaliMinimumVersion ;
 			QString reverseString ;
 			QString idleString ;
-			QString incorrectPasswordText ;
 			QString incorrectPassWordCode ;
 			QString configFileArgument ;
 			QString keyFileArgument ;
@@ -522,6 +521,7 @@ public:
 			QString createControlStructure ;
 			QString defaultFavoritesMountOptions ;
 
+			QStringList incorrectPasswordText ;
 			QStringList executableNames ;
 			QStringList windowsUnMountCommand ;
 			QStringList unMountCommand ;
@@ -597,6 +597,7 @@ public:
 		const QStringList& configFileNames() const ;
 		const QStringList& fileExtensions() const ;
 		const QStringList& volumePropertiesCommands() const ;
+		const QStringList& incorrectPasswordText() const ;
 
 		const engines::version& installedVersion() const ;
 
@@ -617,7 +618,6 @@ public:
 		const QString& keyFileArgument() const ;
 		const QString& mountControlStructure() const ;
 		const QString& createControlStructure() const ;
-		const QString& incorrectPasswordText() const ;
 		const QString& incorrectPasswordCode() const ;
 		const QString& configFileArgument() const ;
 		const QString& windowsInstallPathRegistryKey() const ;
@@ -700,11 +700,54 @@ public:
 
 		virtual volumeInfo::List mountInfo( const volumeInfo::List& ) const ;
 
+		virtual bool canShowVolumeProperties() const ;
+
 		virtual Task::future< QString >& volumeProperties( const QString& cipherFolder,
 								   const QString& mountPoint ) const ;
 
 		virtual engines::engine::status unmount( const engines::engine::unMount& ) const ;
 
+		class commandStatusOpts
+		{
+		public:
+			commandStatusOpts( utility::Task s,
+					   const engines::engine::args& e,
+					   bool creating ) :
+				m_task( std::move( s ) ),m_args( e ),m_creating( creating )
+			{
+			}
+			const QByteArray& stdOut() const
+			{
+				return m_task.stdOut() ;
+			}
+			const QByteArray& stdError() const
+			{
+				return m_task.stdError() ;
+			}
+			bool success() const
+			{
+				return m_task.success() ;
+			}
+			int exitCode() const
+			{
+				return m_task.exitCode() ;
+			}
+			const engines::engine::args& args() const
+			{
+				return m_args ;
+			}
+			bool creating() const
+			{
+				return m_creating ;
+			}
+		private:
+			utility::Task m_task ;
+			const engines::engine::args& m_args ;
+			bool m_creating ;
+		} ;
+
+		virtual engines::engine::cmdStatus commandStatus( const commandStatusOpts& ) const ;
+
 		virtual bool requiresAPassword( const engines::engine::cmdArgsList& ) const ;
 
 		virtual bool takesTooLongToUnlock() const ;
