@@ -57,9 +57,9 @@ static engines::engine::BaseOptions _setOptions()
 	s.acceptsVolName        = true ;
 	s.passwordFormat        = "%{password}" ;
 	s.idleString            = "--unmount-idle %{timeout}" ;
-	s.incorrectPasswordText = "Could not load config file. Did you enter the correct password?" ;
 	s.configFileArgument    = "--config %{configFilePath}" ;
 	s.releaseURL            = "https://api.github.com/repos/cryfs/cryfs/releases" ;
+	s.incorrectPasswordText = QStringList{ "Could not load config file. Did you enter the correct password?" } ;
 	s.successfulMountedList = QStringList{ "Mounting filesystem." } ;
 	s.configFileNames       = QStringList{ "cryfs.config",".cryfs.config" } ;
 	s.fuseNames             = QStringList{ "fuse.cryfs" } ;
@@ -105,6 +105,30 @@ bool cryfs::takesTooLongToUnlock() const
 	return m_version_greater_or_equal_0_10_0 ;
 }
 
+engines::engine::cmdStatus cryfs::commandStatus( const engines::engine::commandStatusOpts& e ) const
+{
+	if( utility::platformIsWindows() ){
+
+		return engines::engine::commandStatus( e ) ;
+	}else{
+		const auto& engine = *this ;
+
+		auto n = engine.errorCode( e.stdOut(),e.stdError(),e.exitCode() ) ;
+
+		if( e.success() ){
+
+			if( n == engines::engine::status::backendCrashed ){
+
+				return { n,engine,e.stdError() } ;
+			}else{
+				return { engines::engine::status::success,engine } ;
+			}
+		}else{
+			return { n,engine,e.stdOut() } ;
+		}
+	}
+}
+
 const QProcessEnvironment& cryfs::getProcessEnvironment() const
 {
 	return m_env ;
@@ -141,10 +165,23 @@ engines::engine::status cryfs::errorCode( const QString& e,const QString& err,in
 			return engines::engine::status::cryfsReplaceFileSystem ;
 		}
 	}else{
+		auto _wrong_password = []( const QString& e,const char * s,const QStringList& m ){
+
+			for( const auto& a : m ){
+
+				if( utility::containsAtleastOne( e,s,a ) ){
+
+					return true ;
+				}
+			}
+
+			return false ;
+		} ;
+
 		/*
 		 * Falling back to parsing strings
 		 */
-		if( utility::containsAtleastOne( e,"Error 11:",this->incorrectPasswordText() ) ){
+		if( _wrong_password( e,"Error 11:",this->incorrectPasswordText() ) ){
 
 			return engines::engine::status::badPassword ;
 
