@@ -57,7 +57,6 @@ static void _parse( engines::engine::BaseOptions& s,const SirikaliJson& json )
 	s.createControlStructure          = json.getString( "createControlStructure" ) ;
 	s.reverseString                   = json.getString( "reverseString" ) ;
 	s.idleString                      = json.getString( "idleString" ) ;
-	s.incorrectPasswordText           = json.getString( "wrongPasswordText" ) ;
 	s.incorrectPassWordCode           = json.getString( "wrongPasswordErrorCode" ) ;
 	s.configFileArgument              = json.getString( "configFileArgument" ) ;
 	s.keyFileArgument                 = json.getString( "keyFileArgument" ) ;
@@ -68,6 +67,8 @@ static void _parse( engines::engine::BaseOptions& s,const SirikaliJson& json )
 	s.versionMinimum                  = json.getString( "versionMinimum" ) ;
 	s.sirikaliMinimumVersion          = json.getString( "sirikaliMinimumVersion" ) ;
 
+	s.incorrectPasswordText           = QStringList{ json.getString( "wrongPasswordText" ) } ;
+
 	s.executableNames                 = QStringList{ json.getString( "executableName" ) } ;
 
 	s.windowsUnMountCommand           = json.getStringList( "windowsUnMountCommand" ) ;
@@ -158,7 +159,7 @@ static void _add_engines( const QString& path,
 	}
 }
 
-void custom::addEngines( std::vector< std::unique_ptr< engines::engine >>& engines )
+void custom::addEngines( std::vector< std::unique_ptr< engines::engine > >& engines )
 {
 	auto m = settings::instance().ConfigLocation() ;
 
@@ -197,9 +198,22 @@ engines::engine::status custom::errorCode( const QString& e,const QString&,int s
 			return engines::engine::status::backendFail ;
 		}
 	}else{
+		auto _wrong_password = []( const QString& e,const QStringList& m ){
+
+			for( const auto& a : m ){
+
+				if( e.contains( a ) ){
+
+					return true ;
+				}
+			}
+
+			return false ;
+		} ;
+
 		const auto& s = this->incorrectPasswordText() ;
 
-		if( !s.isEmpty() && e.contains( s ) ){
+		if( !s.isEmpty() && _wrong_password( e,s ) ){
 
 			return engines::engine::status::badPassword ;
 
