@@ -35,7 +35,7 @@ public:
 
 	custom( engines::engine::BaseOptions baseOpts ) ;
 
-	engines::engine::status errorCode( const QString& e,int s ) const override ;
+	engines::engine::status errorCode( const QString& e,const QString& err,int s ) const override ;
 
 	void GUICreateOptions( const engines::engine::createGUIOptions& ) const override ;
 private:
