@@ -186,6 +186,8 @@ static int _run( App& app,Function function )
 
 int sirikali::run( const QStringList& args,int argc,char * argv[] )
 {
+	std::srand( std::time( nullptr ) ) ;
+
 	if( utility::containsAtleastOne( args,"-s","-u","-p","-T","-b" ) ){
 
 		auto mm = utility::cmdArgumentValue( args,"-b" ) ;
@@ -213,7 +215,10 @@ int sirikali::run( const QStringList& args,int argc,char * argv[] )
 		QApplication srk( argc,argv ) ;
 
 		srk.setApplicationName( "SiriKali" ) ;
-		srk.setDesktopFileName( "io.github.mhogomchungu.sirikali" ) ;
+
+		#if QT_VERSION >= QT_VERSION_CHECK( 5,11,3 )
+			srk.setDesktopFileName( "io.github.mhogomchungu.sirikali" ) ;
+		#endif
 
 		return starter( args,srk ).exec() ;
 	}
@@ -1364,13 +1369,18 @@ void sirikali::volumeProperties()
 
 	const auto& engine = engines::instance().getByName( volumeType ) ;
 
-	auto s = engine.volumeProperties( cipherPath,mountPath ).await() ;
+	if( engine.canShowVolumeProperties() ){
 
-	if( s.isEmpty() ){
+		auto s = engine.volumeProperties( cipherPath,mountPath ).await() ;
 
+		if( s.isEmpty() ){
+
+			this->genericVolumeProperties() ;
+		}else {
+			return DialogMsg( this ).ShowUIInfo( tr( "INFORMATION" ),true,s ) ;
+		}
+	}else{
 		this->genericVolumeProperties() ;
-	}else {
-		return DialogMsg( this ).ShowUIInfo( tr( "INFORMATION" ),true,s ) ;
 	}
 }
 
@@ -1448,6 +1458,13 @@ void sirikali::showContextMenu( QTableWidgetItem * item,bool itemClicked )
 		connect( ac,SIGNAL( triggered() ),this,slot ) ;
 	} ;
 
+	auto oo = settings::instance().openWith() ;
+
+	if( oo.size() > 1 ){
+
+		_addAction( tr( "Open Folder With %1" ).arg( oo.at( 0 ) ),SLOT( openWith() ) ) ;
+	}
+
 	//_addAction( tr( "Open Parent Folder" ),SLOT( slotOpenParentFolder() ) ) ;
 
 	_addAction( tr( "Open Folder" ),SLOT( slotOpenFolder() ) ) ;
@@ -1542,6 +1559,40 @@ void sirikali::slotOpenFolder()
 	}
 }
 
+void sirikali::openWith()
+{
+	auto table = m_ui->tableWidget ;
+
+	if( table->rowCount() > 0 ){
+
+		auto item = table->currentItem() ;
+		auto path = table->item( item->row(),1 )->text() ;
+
+		if( utility::platformIsWindows() ){
+
+			path = path.replace( "/","\\" ) ;
+		}
+
+		auto oo = settings::instance().openWith() ;
+
+		if( oo.size() > 1 ){
+
+			auto exe = oo.at( 1 ) ;
+
+			QStringList args ;
+
+			for( int i = 2 ; i < oo.size() ; i++ ){
+
+				args.append( oo[ i ] ) ;
+			}
+
+			args.append( path ) ;
+
+			utility::Task::run( exe,args ).start() ;
+		}
+	}
+}
+
 void sirikali::slotOpenParentFolder()
 {
 	auto table = m_ui->tableWidget ;
