@@ -173,11 +173,45 @@ namespace utility2
 		return raii< Function >( std::move( function ) ) ;
 	}
 
+	template< typename T,std::enable_if_t< std::is_reference< T >::value,int > = 0 >
+	class result_ref
+	{
+	public:
+		result_ref() : m_value( nullptr )
+		{
+		}
+		result_ref( T e ) : m_value( std::addressof( e ) )
+		{
+		}
+		typename std::remove_reference< T >::type * operator->() const
+		{
+			return m_value ;
+		}
+		T& value() const
+		{
+			return *m_value ;
+		}
+		T& operator*() const
+		{
+			return this->value() ;
+		}
+		bool has_value() const
+		{
+			return m_value != nullptr ;
+		}
+		operator bool() const
+		{
+			return this->has_value() ;
+		}
+	private:
+		typename std::remove_reference< T >::type * m_value ;
+	} ;
+
 	template< typename T >
 	class result
 	{
 	public:
-		result()
+		result() : m_valid( false )
 		{
 		}
 		result( T e ) : m_valid( true ),m_value( std::move( e ) )
@@ -199,7 +233,7 @@ namespace utility2
 		{
 			return m_value ;
 		}
-		operator bool()
+		operator bool() const
 		{
 			return m_valid ;
 		}
@@ -225,7 +259,7 @@ namespace utility2
 			m_valid = true ;
 		}
 	private:
-		bool m_valid = false ;
+		bool m_valid ;
 		T m_value ;
 	} ;
 }
@@ -259,4 +293,9 @@ namespace utility2
 	}
 }
 
+namespace utility2
+{
+	enum class LOGLEVEL{ NOLOG,COMMAND_ONLY,COMMAND_AND_UNLOCK_DURATION } ;
+}
+
 #endif
